Index: src/Fl_Text_Editor.cxx
===================================================================
--- src/Fl_Text_Editor.cxx	(revision 11746)
+++ src/Fl_Text_Editor.cxx	(working copy)
@@ -172,7 +172,14 @@
 }
 
 /**  Returns the function associated with a key binding.*/
-Fl_Text_Editor::Key_Func Fl_Text_Editor::bound_key_function(int key, int state, Key_Binding* list) {
+#if FLTK_ABI_VERSION >= 10304
+// NEW: CONST
+Fl_Text_Editor::Key_Func Fl_Text_Editor::bound_key_function(int key, int state, Key_Binding* list) const
+#else
+// OLD: NON-CONST
+Fl_Text_Editor::Key_Func Fl_Text_Editor::bound_key_function(int key, int state, Key_Binding* list)
+#endif
+{
   Key_Binding* cur;
   for (cur = list; cur; cur = cur->next)
     if (cur->key == key)
Index: FL/Fl_Text_Editor.H
===================================================================
--- FL/Fl_Text_Editor.H	(revision 11746)
+++ FL/Fl_Text_Editor.H	(working copy)
@@ -66,6 +66,56 @@
     */
     int insert_mode() { return insert_mode_; }
 
+#if FLTK_ABI_VERSION >= 10304
+    /**
+    Enables or disables Tab key focus navigation.
+    
+    When disabled (default), tab characters are inserted into
+    Fl_Text_Editor. Only the mouse can change focus.  This behavior is
+    desireable when Fl_Text_Editor is used, e.g. in a source code editor.
+
+    When enabled, Tab navigates focus to the next widget, and Shift-Tab
+    navigates focus to the previous widget. This behavior is desireable
+    when Fl_Text_Editor is used e.g. in a database input form.
+
+    Currently, this method is implimented as a convenience method
+    that adjusts the key bindings for the Tab key. This implementation
+    detail may change in the future. Know that changing the editor's
+    key bindings for Tab and Shift-Tab may affect tab navigation.
+
+    \param [in] val If \p val is 0, Tab inserts a tab character (default).
+                    If \p val is 1, Tab navigates widget focus.<BR>
+
+    \see tab_nav(), Fl::OPTION_ARROW_FOCUS.
+    \version 1.3.4 ABI feature
+    */
+    void tab_nav(int val) {
+      if ( val )
+        add_key_binding(FL_Tab, 0, kf_ignore);
+      else
+        remove_key_binding(FL_Tab, 0);
+    }
+
+    /**
+    Check if Tab focus navigation is enabled.
+
+    If disabled (default), hitting Tab inserts a tab character into the
+    editor buffer.
+
+    If enabled, hitting Tab navigates focus to the next widget,
+    and Shift-Tab navigates focus to the previous widget.
+
+    \returns 0 if Tab inserts tab characters (default), 1 if Tab navigation is enabled.
+    \see tab_nav(int), Fl::OPTION_ARROW_FOCUS.
+    \version 1.3.4 ABI feature
+    */
+    int tab_nav() const {
+      if ( bound_key_function(FL_Tab, 0) == kf_ignore )
+        return(1);
+      else
+        return(0);
+    }
+#endif
     void add_key_binding(int key, int state, Key_Func f, Key_Binding** list);
     /** Adds a \p key of state \p state with the function \p f. */
     void add_key_binding(int key, int state, Key_Func f)
@@ -78,10 +128,19 @@
     /** Removes all of the key bindings associated with the text editor or list. */
     void remove_all_key_bindings() { remove_all_key_bindings(&key_bindings); }
     void add_default_key_bindings(Key_Binding** list);
+#if FLTK_ABI_VERSION >= 10304
+    // NEW: CONST
+    Key_Func bound_key_function(int key, int state, Key_Binding* list) const;
+    /**  Returns the function associated with a key binding. */
+    Key_Func bound_key_function(int key, int state) const
+      { return bound_key_function(key, state, key_bindings); }
+#else
+    // OLD: NON-CONST
     Key_Func bound_key_function(int key, int state, Key_Binding* list);
     /**  Returns the function associated with a key binding. */
     Key_Func bound_key_function(int key, int state)
       { return bound_key_function(key, state, key_bindings); }
+#endif
     /**  Sets the default key function for unassigned keys. */
     void default_key_function(Key_Func f) { default_key_function_ = f; }
 
